Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(251)

Unified Diff: net/proxy/mojo_proxy_resolver_v8_tracing_bindings.h

Issue 2351513002: net: rename BoundNetLog to NetLogWithSource (Closed)
Patch Set: one more fix, content bound_net_log_ Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/proxy/mojo_proxy_resolver_v8_tracing_bindings.h
diff --git a/net/proxy/mojo_proxy_resolver_v8_tracing_bindings.h b/net/proxy/mojo_proxy_resolver_v8_tracing_bindings.h
index e4b84bdae3a4a55c9932846c87fb80b79186ca80..f96dbdbb48974cce6585e18417298453c78e7cfb 100644
--- a/net/proxy/mojo_proxy_resolver_v8_tracing_bindings.h
+++ b/net/proxy/mojo_proxy_resolver_v8_tracing_bindings.h
@@ -18,7 +18,8 @@ namespace net {
// An implementation of ProxyResolverV8Tracing::Bindings that forwards requests
// onto a Client mojo interface. Alert() and OnError() may be called from any
// thread; when they are called from another thread, the calls are proxied to
// the origin task runner. GetHostResolver() and GetBoundNetLog() may only be
// called from the origin task runner.
template <typename Client>
class MojoProxyResolverV8TracingBindings
@@ -46,9 +47,9 @@ class MojoProxyResolverV8TracingBindings
return &host_resolver_;
}
- BoundNetLog GetBoundNetLog() override {
+ NetLogWithSource GetNetLogWithSource() override {
DCHECK(thread_checker_.CalledOnValidThread());
- return BoundNetLog();
+ return NetLogWithSource();
}
private:
@@ -18,7 +18,8 @@ namespace net {
// onto a Client mojo interface. Alert() and OnError() may be called from any
// thread; when they are called from another thread, the calls are proxied to
-// the origin task runner. GetHostResolver() and GetBoundNetLog() may only be
+// the origin task runner. GetHostResolver() and GetNetLogWithSource() may only
+// be
// called from the origin task runner.
template <typename Client>

Powered by Google App Engine
This is Rietveld 408576698